bayespy.inference.vmp.nodes.constant.Constant.has_plotter
=========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.constant

.. automethod:: Constant.has_plotter